<template>
  <el-dialog
    width="60%"
    title="不合格零件"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="250"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      :selColValArr="paramSelArr"
      :selCol="paramSelCol"
      ref="commonOutputPartTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >确 定</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { fetchListApplyPartForUnqualified } from '@/api/quality/apply'
import { addUnqualifiedProcessPart } from '@/api/quality/unqualifiedprocess'
import ttable from '@/views/common/ztt-table'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    unqualifiedProcessId: {
      type: Number,
      default: 0
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    // 默认选中字段的值数组
    paramSelArr: {
      type: Array,
      default: () => {
        return []
      }
    },
    // 默认选中字段
    paramSelCol: {
      type: String
    }
  },
  data() {
    return {
      ajaxFun: fetchListApplyPartForUnqualified,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        isGeneralSearch: true,
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'systemNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '110',
            minWidth: '110',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '110',
            minWidth: '110',
            prop: 'outBatchNo',
            label: '系统批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '110',
            minWidth: '110',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            minWidth: '140',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'unqualifiedArrived',
            label: '不合格数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            minWidth: '140',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '110',
            minWidth: '110',
            prop: 'applyNo',
            label: '检测申请编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '110',
            minWidth: '110',
            prop: 'reportNo',
            label: '检测汇报编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      isSubmit: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      this.$emit('handleSelectionChange', this.multipleSelection)
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.commonOutputPartTable !== undefined) {
        this.$refs.commonOutputPartTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}

.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}

.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
